Mesa (master): scons: Don't use gstabs on mingw-64.

Jose Fonseca jrfonseca at kemper.freedesktop.org
Mon Sep 12 16:52:49 UTC 2011


Module: Mesa
Branch: master
Commit: fb5995cf53000af3bd32ca6effb4b08c4aaffe17
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=fb5995cf53000af3bd32ca6effb4b08c4aaffe17

Author: José Fonseca <jfonseca at vmware.com>
Date:   Mon Sep 12 17:23:47 2011 +0100

scons: Don't use gstabs on mingw-64.

---

 scons/crossmingw.py |    8 +++++---
 1 files changed, 5 insertions(+), 3 deletions(-)

diff --git a/scons/crossmingw.py b/scons/crossmingw.py
index 893002f..23c56c0 100644
--- a/scons/crossmingw.py
+++ b/scons/crossmingw.py
@@ -221,9 +221,11 @@ def generate(env):
     env['LIBPREFIXES']    = [ 'lib', '' ]
     env['LIBSUFFIXES']    = [ '.a', '.lib' ]
 
-    # MinGW port of gdb does not handle well dwarf debug info which is the
-    # default in recent gcc versions
-    env.AppendUnique(CCFLAGS = ['-gstabs'])
+    # MinGW x86 port of gdb does not handle well dwarf debug info which is the
+    # default in recent gcc versions.  The x64 port gdb from mingw-w64 seems to
+    # handle it fine though, so stick with the default there.
+    if env['machine'] != 'x86_64':
+        env.AppendUnique(CCFLAGS = ['-gstabs'])
 
     env.AddMethod(compile_without_gstabs, 'compile_without_gstabs')
 




More information about the mesa-commit mailing list